/*
 * Copyright 2013 MongoDB, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef MONGOC_TESTS_H
#define MONGOC_TESTS_H

#include <bson.h>
#include <stdio.h>
#include <time.h>
#ifdef _WIN32
#include <process.h>
#endif


BSON_BEGIN_DECLS

void
run_test (const char *name, void (*func) (void));

BSON_END_DECLS

#endif /* MONGOC_TESTS_H */
